==> jc-1.4.0.tar.gz: java/awt/font/TextAttribute.h <==
// public final class java.awt.font.TextAttribute

// class file dependencies
// @dep_class 2d6db4dbb67b78cc java_awt_font_TextAttribute
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d8de555b0e6a3b60 java_text_AttributedCharacterIterator__24Attribute

// header file dependencies
// @dep_header java_text_AttributedCharacterIterator__24Attribute

#include "java/text/AttributedCharacterIterator__24Attribute.h"

#ifndef _JC_java_awt_font_TextAttribute_H_
#define _JC_java_awt_font_TextAttribute_H_

// Forward structure declarations
struct _jc_java_awt_font_TextAttribute$object;
struct _jc_java_lang_Boolean$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Float$object;
struct _jc_java_lang_Integer$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_font_TextAttribute$sub_refs	_jc_java_awt_font_TextAttribute$sub_refs;
typedef struct _jc_java_awt_font_TextAttribute$sub_nonrefs	_jc_java_awt_font_TextAttribute$sub_nonrefs;
typedef struct _jc_java_awt_font_TextAttribute$refs	_jc_java_awt_font_TextAttribute$refs;
typedef struct _jc_java_awt_font_TextAttribute$nonrefs	_jc_java_awt_font_TextAttribute$nonrefs;
typedef struct _jc_java_awt_font_TextAttribute$object	_jc_java_awt_font_TextAttribute$object;

typedef struct _jc_java_awt_font_TextAttribute$fields_struct	_jc_java_awt_font_TextAttribute$fields_struct;
typedef const struct _jc_java_awt_font_TextAttribute$vmethods	_jc_java_awt_font_TextAttribute$vmethods;
typedef const struct _jc_java_awt_font_TextAttribute$vtable	_jc_java_awt_font_TextAttribute$vtable;
typedef const struct _jc_java_awt_font_TextAttribute$vtype	_jc_java_awt_font_TextAttribute$vtype;

// Class fields structure
struct _jc_java_awt_font_TextAttribute$fields_struct {
	struct _jc_java_awt_font_TextAttribute$object	*BACKGROUND;
	struct _jc_java_awt_font_TextAttribute$object	*BIDI__5fEMBEDDING;
	struct _jc_java_awt_font_TextAttribute$object	*CHAR__5fREPLACEMENT;
	struct _jc_java_awt_font_TextAttribute$object	*FAMILY;
	struct _jc_java_awt_font_TextAttribute$object	*FONT;
	struct _jc_java_awt_font_TextAttribute$object	*FOREGROUND;
	struct _jc_java_awt_font_TextAttribute$object	*INPUT__5fMETHOD__5fHIGHLIGHT;
	struct _jc_java_awt_font_TextAttribute$object	*INPUT__5fMETHOD__5fUNDERLINE;
	struct _jc_java_awt_font_TextAttribute$object	*JUSTIFICATION;
	struct _jc_java_lang_Float$object	*JUSTIFICATION__5fFULL;
	struct _jc_java_lang_Float$object	*JUSTIFICATION__5fNONE;
	struct _jc_java_awt_font_TextAttribute$object	*NUMERIC__5fSHAPING;
	struct _jc_java_awt_font_TextAttribute$object	*POSTURE;
	struct _jc_java_lang_Float$object	*POSTURE__5fOBLIQUE;
	struct _jc_java_lang_Float$object	*POSTURE__5fREGULAR;
	struct _jc_java_awt_font_TextAttribute$object	*RUN__5fDIRECTION;
	struct _jc_java_lang_Boolean$object	*RUN__5fDIRECTION__5fLTR;
	struct _jc_java_lang_Boolean$object	*RUN__5fDIRECTION__5fRTL;
	struct _jc_java_awt_font_TextAttribute$object	*SIZE;
	struct _jc_java_awt_font_TextAttribute$object	*STRIKETHROUGH;
	struct _jc_java_lang_Boolean$object	*STRIKETHROUGH__5fON;
	struct _jc_java_awt_font_TextAttribute$object	*SUPERSCRIPT;
	struct _jc_java_lang_Integer$object	*SUPERSCRIPT__5fSUB;
	struct _jc_java_lang_Integer$object	*SUPERSCRIPT__5fSUPER;
	struct _jc_java_awt_font_TextAttribute$object	*SWAP__5fCOLORS;
	struct _jc_java_lang_Boolean$object	*SWAP__5fCOLORS__5fON;
	struct _jc_java_awt_font_TextAttribute$object	*TRANSFORM;
	struct _jc_java_awt_font_TextAttribute$object	*UNDERLINE;
	struct _jc_java_lang_Integer$object	*UNDERLINE__5fLOW__5fDASHED;
	struct _jc_java_lang_Integer$object	*UNDERLINE__5fLOW__5fDOTTED;
	struct _jc_java_lang_Integer$object	*UNDERLINE__5fLOW__5fGRAY;
	struct _jc_java_lang_Integer$object	*UNDERLINE__5fLOW__5fONE__5fPIXEL;
	struct _jc_java_lang_Integer$object	*UNDERLINE__5fLOW__5fTWO__5fPIXEL;
	struct _jc_java_lang_Integer$object	*UNDERLINE__5fON;
	struct _jc_java_awt_font_TextAttribute$object	*WEIGHT;
	struct _jc_java_lang_Float$object	*WEIGHT__5fBOLD;
	struct _jc_java_lang_Float$object	*WEIGHT__5fDEMIBOLD;
	struct _jc_java_lang_Float$object	*WEIGHT__5fDEMILIGHT;
	struct _jc_java_lang_Float$object	*WEIGHT__5fEXTRABOLD;
	struct _jc_java_lang_Float$object	*WEIGHT__5fEXTRA__5fLIGHT;
	struct _jc_java_lang_Float$object	*WEIGHT__5fHEAVY;
	struct _jc_java_lang_Float$object	*WEIGHT__5fLIGHT;
	struct _jc_java_lang_Float$object	*WEIGHT__5fMEDIUM;
	struct _jc_java_lang_Float$object	*WEIGHT__5fREGULAR;
	struct _jc_java_lang_Float$object	*WEIGHT__5fSEMIBOLD;
	struct _jc_java_lang_Float$object	*WEIGHT__5fULTRABOLD;
	struct _jc_java_awt_font_TextAttribute$object	*WIDTH;
	struct _jc_java_lang_Float$object	*WIDTH__5fCONDENSED;
	struct _jc_java_lang_Float$object	*WIDTH__5fEXTENDED;
	struct _jc_java_lang_Float$object	*WIDTH__5fREGULAR;
	struct _jc_java_lang_Float$object	*WIDTH__5fSEMI__5fCONDENSED;
	struct _jc_java_lang_Float$object	*WIDTH__5fSEMI__5fEXTENDED;
	jlong	serialVersionUID;
};
extern _jc_java_awt_font_TextAttribute$fields_struct _jc_java_awt_font_TextAttribute$class_fields;

// Constructors
extern void _jc_java_awt_font_TextAttribute$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_font_TextAttribute$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_font_TextAttribute$method$readResolve$3c2bccd3a831d3ae(_jc_env *, struct _jc_java_awt_font_TextAttribute$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_font_TextAttribute$method_info$readResolve$3c2bccd3a831d3ae;

// Static methods
extern void _jc_java_awt_font_TextAttribute$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_font_TextAttribute$vmethods {
	struct _jc_java_lang_Object$object	*(*readResolve$3c2bccd3a831d3ae)(_jc_env *, struct _jc_java_awt_font_TextAttribute$object *);
};

// Vtable
struct _jc_java_awt_font_TextAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_AttributedCharacterIterator__24Attribute$vmethods	java_text_AttributedCharacterIterator__24Attribute;
	_jc_java_awt_font_TextAttribute$vmethods	java_awt_font_TextAttribute;
};

// Vtype
struct _jc_java_awt_font_TextAttribute$vtype {
	_jc_type			type;
	_jc_java_awt_font_TextAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_font_TextAttribute$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_font_TextAttribute$refs {
    _jc_java_awt_font_TextAttribute$sub_refs	java_awt_font_TextAttribute;
    _jc_java_text_AttributedCharacterIterator__24Attribute$sub_refs	java_text_AttributedCharacterIterator__24Attribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_font_TextAttribute$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_font_TextAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_AttributedCharacterIterator__24Attribute$sub_nonrefs	java_text_AttributedCharacterIterator__24Attribute;
    _jc_java_awt_font_TextAttribute$sub_nonrefs	java_awt_font_TextAttribute;
};

// Object instance structure
struct _jc_java_awt_font_TextAttribute$object {
	_jc_java_awt_font_TextAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_font_TextAttribute$vtype	*vtype;
	_jc_java_awt_font_TextAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_font_TextAttribute$vtype _jc_java_awt_font_TextAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_font_TextAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_font_TextAttribute$class_object;

#endif	/* _JC_java_awt_font_TextAttribute_H_ */

==> jc-1.4.6.tar.gz: java/awt/font/TextAttribute.h <==
// public final class java.awt.font.TextAttribute

// class file dependencies
// @dep_class 2d6db4dbb67b78cc java_awt_font_TextAttribute
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d8de555b0e6a3b60 java_text_AttributedCharacterIterator__24Attribute

// header file dependencies
// @dep_header java_text_AttributedCharacterIterator__24Attribute

#include "java/text/AttributedCharacterIterator__24Attribute.h"

#ifndef _JC_java_awt_font_TextAttribute_H_
#define _JC_java_awt_font_TextAttribute_H_

// Forward structure declarations
struct _jc_java_awt_font_TextAttribute$object;
struct _jc_java_lang_Boolean$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Float$object;
struct _jc_java_lang_Integer$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_font_TextAttribute$sub_refs	_jc_java_awt_font_TextAttribute$sub_refs;
typedef struct _jc_java_awt_font_TextAttribute$sub_nonrefs	_jc_java_awt_font_TextAttribute$sub_nonrefs;
typedef struct _jc_java_awt_font_TextAttribute$refs	_jc_java_awt_font_TextAttribute$refs;
typedef struct _jc_java_awt_font_TextAttribute$nonrefs	_jc_java_awt_font_TextAttribute$nonrefs;
typedef struct _jc_java_awt_font_TextAttribute$object	_jc_java_awt_font_TextAttribute$object;

typedef struct _jc_java_awt_font_TextAttribute$fields_struct	_jc_java_awt_font_TextAttribute$fields_struct;
typedef const struct _jc_java_awt_font_TextAttribute$vmethods	_jc_java_awt_font_TextAttribute$vmethods;
typedef const struct _jc_java_awt_font_TextAttribute$vtable	_jc_java_awt_font_TextAttribute$vtable;
typedef const struct _jc_java_awt_font_TextAttribute$vtype	_jc_java_awt_font_TextAttribute$vtype;

// Class fields structure
struct _jc_java_awt_font_TextAttribute$fields_struct {
	struct _jc_java_awt_font_TextAttribute$object	*BACKGROUND;
	struct _jc_java_awt_font_TextAttribute$object	*BIDI__5fEMBEDDING;
	struct _jc_java_awt_font_TextAttribute$object	*CHAR__5fREPLACEMENT;
	struct _jc_java_awt_font_TextAttribute$object	*FAMILY;
	struct _jc_java_awt_font_TextAttribute$object	*FONT;
	struct _jc_java_awt_font_TextAttribute$object	*FOREGROUND;
	struct _jc_java_awt_font_TextAttribute$object	*INPUT__5fMETHOD__5fHIGHLIGHT;
	struct _jc_java_awt_font_TextAttribute$object	*INPUT__5fMETHOD__5fUNDERLINE;
	struct _jc_java_awt_font_TextAttribute$object	*JUSTIFICATION;
	struct _jc_java_lang_Float$object	*JUSTIFICATION__5fFULL;
	struct _jc_java_lang_Float$object	*JUSTIFICATION__5fNONE;
	struct _jc_java_awt_font_TextAttribute$object	*NUMERIC__5fSHAPING;
	struct _jc_java_awt_font_TextAttribute$object	*POSTURE;
	struct _jc_java_lang_Float$object	*POSTURE__5fOBLIQUE;
	struct _jc_java_lang_Float$object	*POSTURE__5fREGULAR;
	struct _jc_java_awt_font_TextAttribute$object	*RUN__5fDIRECTION;
	struct _jc_java_lang_Boolean$object	*RUN__5fDIRECTION__5fLTR;
	struct _jc_java_lang_Boolean$object	*RUN__5fDIRECTION__5fRTL;
	struct _jc_java_awt_font_TextAttribute$object	*SIZE;
	struct _jc_java_awt_font_TextAttribute$object	*STRIKETHROUGH;
	struct _jc_java_lang_Boolean$object	*STRIKETHROUGH__5fON;
	struct _jc_java_awt_font_TextAttribute$object	*SUPERSCRIPT;
	struct _jc_java_lang_Integer$object	*SUPERSCRIPT__5fSUB;
	struct _jc_java_lang_Integer$object	*SUPERSCRIPT__5fSUPER;
	struct _jc_java_awt_font_TextAttribute$object	*SWAP__5fCOLORS;
	struct _jc_java_lang_Boolean$object	*SWAP__5fCOLORS__5fON;
	struct _jc_java_awt_font_TextAttribute$object	*TRANSFORM;
	struct _jc_java_awt_font_TextAttribute$object	*UNDERLINE;
	struct _jc_java_lang_Integer$object	*UNDERLINE__5fLOW__5fDASHED;
	struct _jc_java_lang_Integer$object	*UNDERLINE__5fLOW__5fDOTTED;
	struct _jc_java_lang_Integer$object	*UNDERLINE__5fLOW__5fGRAY;
	struct _jc_java_lang_Integer$object	*UNDERLINE__5fLOW__5fONE__5fPIXEL;
	struct _jc_java_lang_Integer$object	*UNDERLINE__5fLOW__5fTWO__5fPIXEL;
	struct _jc_java_lang_Integer$object	*UNDERLINE__5fON;
	struct _jc_java_awt_font_TextAttribute$object	*WEIGHT;
	struct _jc_java_lang_Float$object	*WEIGHT__5fBOLD;
	struct _jc_java_lang_Float$object	*WEIGHT__5fDEMIBOLD;
	struct _jc_java_lang_Float$object	*WEIGHT__5fDEMILIGHT;
	struct _jc_java_lang_Float$object	*WEIGHT__5fEXTRABOLD;
	struct _jc_java_lang_Float$object	*WEIGHT__5fEXTRA__5fLIGHT;
	struct _jc_java_lang_Float$object	*WEIGHT__5fHEAVY;
	struct _jc_java_lang_Float$object	*WEIGHT__5fLIGHT;
	struct _jc_java_lang_Float$object	*WEIGHT__5fMEDIUM;
	struct _jc_java_lang_Float$object	*WEIGHT__5fREGULAR;
	struct _jc_java_lang_Float$object	*WEIGHT__5fSEMIBOLD;
	struct _jc_java_lang_Float$object	*WEIGHT__5fULTRABOLD;
	struct _jc_java_awt_font_TextAttribute$object	*WIDTH;
	struct _jc_java_lang_Float$object	*WIDTH__5fCONDENSED;
	struct _jc_java_lang_Float$object	*WIDTH__5fEXTENDED;
	struct _jc_java_lang_Float$object	*WIDTH__5fREGULAR;
	struct _jc_java_lang_Float$object	*WIDTH__5fSEMI__5fCONDENSED;
	struct _jc_java_lang_Float$object	*WIDTH__5fSEMI__5fEXTENDED;
	jlong	serialVersionUID;
};
extern _jc_java_awt_font_TextAttribute$fields_struct _jc_java_awt_font_TextAttribute$class_fields;

// Constructors
extern void _jc_java_awt_font_TextAttribute$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_font_TextAttribute$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_font_TextAttribute$method$readResolve$3c2bccd3a831d3ae(_jc_env *, struct _jc_java_awt_font_TextAttribute$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_font_TextAttribute$method_info$readResolve$3c2bccd3a831d3ae;

// Static methods
extern void _jc_java_awt_font_TextAttribute$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_font_TextAttribute$vmethods {
	struct _jc_java_lang_Object$object	*(*readResolve$3c2bccd3a831d3ae)(_jc_env *, struct _jc_java_awt_font_TextAttribute$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_font_TextAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_AttributedCharacterIterator__24Attribute$vmethods	java_text_AttributedCharacterIterator__24Attribute;
	_jc_java_awt_font_TextAttribute$vmethods	java_awt_font_TextAttribute;
};

// Vtype
struct _jc_java_awt_font_TextAttribute$vtype {
	_jc_type			type;
	_jc_java_awt_font_TextAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_font_TextAttribute$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_font_TextAttribute$refs {
    _jc_java_awt_font_TextAttribute$sub_refs	java_awt_font_TextAttribute;
    _jc_java_text_AttributedCharacterIterator__24Attribute$sub_refs	java_text_AttributedCharacterIterator__24Attribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_font_TextAttribute$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_font_TextAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_AttributedCharacterIterator__24Attribute$sub_nonrefs	java_text_AttributedCharacterIterator__24Attribute;
    _jc_java_awt_font_TextAttribute$sub_nonrefs	java_awt_font_TextAttribute;
};

// Object instance structure
struct _jc_java_awt_font_TextAttribute$object {
	_jc_java_awt_font_TextAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_font_TextAttribute$vtype	*vtype;
	_jc_java_awt_font_TextAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_font_TextAttribute$vtype _jc_java_awt_font_TextAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_font_TextAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_font_TextAttribute$class_object;

#endif	/* _JC_java_awt_font_TextAttribute_H_ */
